ReadME
======

.. note:: What WAVES stands for ?

    WAVES stands for "Web Application for Versatile and Easy online bioinformatic Services."

    It is aimed to help you easily present, publish and give access on the web of any bioinformatic tools developed in your teams.

    Based on Python and Django framework, it is easy to maintain and make evolve for your specific requirements.

Features
--------

    - Create and manage you services execution over platform such as Galaxy, DRMAA clusters (SGE), Direct script execution, API calls to other service, remote calls to other platforms via ssh, etc.
    - Easily presents these tools in a nice frontend based on Bootstrap3
    - Follow and manage remote REST API access to your service platform
    - Manage user's access to your services

Installation
------------

    - WAVES web app comply to standard reusable project layout for Django. You can use it as a stand alone platform.
    - Simply clone or download sources, follow the few configurations steps, and her you are, you can put your tools online !
    - See "Details Installation" for more info.

Contribute
----------

.. include:: ../CONTRIBUTING.rst
    :start-line: 4
    :end-line: 8

Support
-------

    If you are having issues, (or just want to say hello) : we have a mailing list located at: waves-webapp@googlegroups.com


